### 0.13.5 {small}`2025-12-13`

```{rubric} Features
```
* Adds support for multi-GPU clustering via Dask to `tl.leiden` and `tl.louvain` {pr}`502` {smaller}`S Dicks`
* Adds support for specifying multiple resolutions as a list in `tl.leiden` and `tl.louvain` {pr}`502` {smaller}`S Dicks`

```{rubric} Performance
```
* Improves `pp.neighbors` performance with `all_neighbors` and `nn_descent` when a Dask cluster is active {pr}`499` {smaller}`S Dicks`

```{rubric} Misc
```
* Update Docker Container to work with `CUDA-13` {pr}`520` {smaller}`S Dicks`
